###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_blob_blog_system_detect.nasl 5241 2009-10-20 12:38:31Z oct $
#
# BLOB Blog System Version Detection
#
# Authors:
# Nikita MR <rnikita@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800955);
  script_version("Revision: 1.0");
  script_tag(name:"risk_factor", value:"None");
  script_name("BLOB Blog System Version Detection");
  desc = "
  Overview: This script detects the installed version of BLOB Blog System
  and sets the result in KB.

  Risk factor: None";

  script_description(desc);
  script_summary("Sets the KB for the version of BLOB Blog System");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 Intevation GmbH");
  script_family("Service detection");
  script_dependencies("http_version.nasl");
  script_require_ports("Services/www", 80);
  exit(0);
}


include("http_func.inc");

bbsPort = get_http_port(default:80);
if(!bbsPort){
  bbsPort = 80;
}

if(!get_port_state(bbsPort)){
  exit(0);
}

foreach dir (make_list("/", "/blob", "/blog", cgi_dirs()))
{
  sndReq = http_get(item:string(dir, "/blob.php"), port:bbsPort);
  rcvRes = http_send_recv(port:bbsPort, data:sndReq);

  if("The BLOB Blog System" >< rcvRes &&
    (egrep(pattern:"^HTTP/.* 200 OK", string:rcvRes)))
  {
    bbsVer = eregmatch(pattern:"Version ([0-9.]+)", string:rcvRes);
    if(!isnull(bbsVer[1]))
    {
      set_kb_item(name:"www/" + bbsPort + "/BLOB-Blog-System",
                  value:bbsVer[1] + " under " + dir);
      security_note(data:"BLOB Blog System version " + bbsVer[1] + " running" + 
                         " at location " + dir +  " was detected on the host");
    }
  }
}
