###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_fsecure_prdts_detect_win.nasl 995 2009-03-12 15:14:29Z mar $
#
# F-Secure Multiple Products Version Detection (Win)
#
# Authors:
# Sharath S <sharaths@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800355);
  script_version("$Revision: 1.1 $");
  script_tag(name:"risk_factor", value:"None");
  script_name("F-Secure Multiple Products Version Detection (Win)");
  desc = "
  Overview: The script detects the installed version of F-Secure Anti-Virus
  (for MS Exchange), Workstations and Internet GateKeeper & sets the version
  in KB.

  Risk Factor: None";

  script_description(desc);
  script_summary("Sets the Version of F-Secure Products");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 Intevation GmbH");
  script_family("Service detection");
  script_dependencies("secpod_reg_enum.nasl");
  script_require_keys("SMB/WindowsVersion");
  script_require_ports(139, 445);
  exit(0);
}


include("smb_nt.inc");
include("secpod_smb_func.inc");

if(!get_kb_item("SMB/WindowsVersion")){
  exit(0);
}

if(!registry_key_exists(key:"SOFTWARE\Data Fellows\F-Secure")){
  exit(0);
}

# Set the Version for F-Secure Anti-Virus
fsavVer = registry_get_sz(key:"SOFTWARE\Data Fellows\F-Secure\Anti-Virus",
                          item:"CurrentVersionEx");
if(fsavVer)
{
  set_kb_item(name:"F-Sec/AV/Win/Ver", value:fsavVer);
  security_note(data:"F-secure Anti Virus version " + fsavVer + " was detected on the host"); 
}

# Set the Version for F-Secure Anti-Virus for Internet Gatekeeper
fsigkVer = registry_get_sz(key:"SOFTWARE\Data Fellows\F-Secure" +
                               "\Anti-Virus for Internet Gateways",
                           item:"CurrentVersion");
if(fsigkVer)
{
  set_kb_item(name:"F-Sec/AV/IntGatekeeper/Win/Ver", value:fsigkVer);
  security_note(data:"F-secure Anti Virus Intrnet Gate Keeper version " 
                      + fsigkVer +  " was detected on the host");
}

# Set the Version for F-Secure Anti-Virus for Microsoft Exchange
fsavmeVer = registry_get_sz(key:"SOFTWARE\Data Fellows\F-Secure" +
                                "\Anti-Virus Agent for Microsoft Exchange",
                            item:"CurrentVersion");
if(fsavmeVer)
{
  set_kb_item(name:"F-Sec/AV/MSExchange/Ver", value:fsavmeVer);
  security_note(data:"F-secure Anti Virus MS Exhange version " + fsavmeVer +
                     " was detected on the host");
}

# Set the Version for F-Secure Anti-Virus for Client Security
fsavcsVer = registry_get_sz(key:"SOFTWARE\Data Fellows\F-Secure\FSAVCSIN",
                            item:"CurrentVersion");
if(fsavcsVer)
{
  set_kb_item(name:"F-Sec/AV/ClientSecurity/Ver", value:fsavcsVer);
  security_note(data:"F-secure Anti Virus Client Security version " + fsavcsVer + 
                     " was detected on the host");
}

# Set the Version for F-Secure Anti-Virus for Windows Servers
fsavwsKey = "SOFTWARE\Data Fellows\F-Secure\TNB\Products\";
foreach item (registry_enum_keys(key:fsavwsKey))
{
  fsavwsName = registry_get_sz(key:fsavwsKey + item, item:"ProductName");

  if("F-Secure Anti-Virus for Windows Servers" >< fsavwsName)
  {
    fsavwsVer = registry_get_sz(key:fsavwsKey + item, item:"Version");
    if(fsavwsVer)
    {
      set_kb_item(name:"F-Sec/AV/WindowsServers/Ver", value:fsavwsVer);
      security_note(data:"F-secure Anti Virus Windows Server version " + fsavwsVer +
                     " was detected on the host");
    }
  }
}
