##############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_openssl_detect_win.nasl 1258 2009-04-01 14:30:24Z apr $
#
# OpenSSL Version Detection (Win)
#
# Authors:
# Sujit Ghosal <sghosal@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800257);
  script_version("$Revision: 1.0 $");
  script_tag(name:"risk_factor", value:"None");
  script_name("OpenSSL Version Detection (Win)");
  desc = "
  Overview : This script finds the installed OpenSSL version and saves the
  result in KB item.

  Risk factor : None";

  script_description(desc);
  script_summary("Set Version of OpenSSL in KB for Windows");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 Intevation GmbH");
  script_family("General");
  script_dependencies("secpod_reg_enum.nasl");
  script_require_keys("SMB/WindowsVersion");
  script_require_ports(139, 445);
  exit(0);
}


include("smb_nt.inc");
include("secpod_smb_func.inc");

if(!get_kb_item("SMB/WindowsVersion")){
  exit(0);
}

key = "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\";

if(!registry_key_exists(key:key)){
    exit(0);
}

foreach item (registry_enum_keys(key:key))
{
  name = registry_get_sz(key:key + item, item:"DisplayName");
  if("OpenSSL" >< name)
  {
    ver = eregmatch(pattern:"([0-9]\.[0-9]\.[0-9.]+[a-z]?)", string:name);
    if(ver[0] != NULL)
    {
      set_kb_item(name:"OpenSSL/Win/Ver", value:ver[0]);
      security_note(data:"OpenSSL version " + ver[0] + " was detected on the host");
    }
    exit(0);
  }
}
