###############################################################################
# OpenVAS Vulnerability Test
# $Id: secpod_adobe_shockwave_player_detect.nasl 3119 2009-06-30 16:00:02Z jun $
#
# Adobe Shockwave Player Version Detection
#
# Authors:
# Nikita MR <rnikita@secpod.com>
#
# Copyright:
# Copyright (c) 2009 SecPod, http://www.secpod.com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(900581);
  script_version("$Revision: 1.0 $");
  script_tag(name:"risk_factor", value:"None");
  script_name("Adobe Shockwave Player Version Detection");
  desc = "

  Overview: This script detects the version of Adobe Shockwave Player
  and sets the version in KB.

  Risk factor: None";

  script_description(desc);
  script_summary("Sets KB for the version of Adobe Shockwave Player");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 SecPod");
  script_family("Service detection");
  script_dependencies("secpod_reg_enum.nasl");
  script_require_keys("SMB/WindowsVersion");
  script_require_ports(139, 445);
  exit(0);
}

include("smb_nt.inc");
include("secpod_smb_func.inc");

if(!get_kb_item("SMB/WindowsVersion")){
  exit(0);
}

if(!registry_key_exists(key:"SOFTWARE\Adobe")){
  if(!registry_key_exists(key:"SOFTWARE\Macromedia"))
    exit(0);
}

key = "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\";
foreach item (registry_enum_keys(key:key))
{
  swplayerName = registry_get_sz(key:key + item, item:"DisplayName");
  if("Shockwave" >< swplayerName)
  {
    unintPath = registry_get_sz(key:key + item, item:"UninstallString");
    break;
  }
}

if(unintPath != NULL)
{
  swPath = registry_get_sz(key:"SOFTWARE\Microsoft\COM3\Setup",
                           item:"Install Path");
  if(swPath == NULL){
    exit(0);
  }

  share = ereg_replace(pattern:"([A-Z]):.*", replace:"\1$", string:swPath);
  if("Adobe" >< unintPath)
  {
    file = ereg_replace(pattern:"[A-Z]:(.*)", replace:"\1",
                        string:swPath + "\Adobe\Shockwave\swinit.exe");
    swVer = GetVer(share:share, file:file);
    if(!swVer)
    {
      for(i=8; i<=11; i++)
      {
        file = ereg_replace(pattern:"[A-Z]:(.*)", replace:"\1", string:swPath +
                                    "\Adobe\Shockwave " + i +"\swinit.exe");
        swVer = GetVer(share:share, file:file);
        if(swVer != NULL){
           break;
        }
      }
    }
  }
  else if("Macromed" >< unintPath)
  {
    file = ereg_replace(pattern:"[A-Z]:(.*)", replace:"\1",
                        string:swPath + "\Macromed\Shockwave\swinit.exe");
    swVer = GetVer(share:share, file:file);
    if(!swVer)
    {
      for(i=8; i<=11; i++)
      {
        file = ereg_replace(pattern:"[A-Z]:(.*)", replace:"\1", string:swPath +
                                    "\Macromed\Shockwave " + i +"\swinit.exe");
        swVer = GetVer(share:share, file:file);
        if(swVer != NULL){
           break;
        }
      }
    }
  }
  if(swVer){
    set_kb_item(name:"Adobe/ShockwavePlayer/Ver", value:swVer);
    security_note(data:"Adobe Shockwave Player version " + swVer +
                       " was detected on the host");
  }
}
