###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_ibm_db2_unspesified_vuln_win.nasl 5093 2009-10-05 17:11:27Z oct $
#
# IBM DB2 Unspecified Vulnerability (Win)
#
# Authors:
# Antu Sanadi <santu@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(801002);
  script_version("$Revision: 1.0 $");
  script_tag(name:"cvss_base", value:"10.0");
  script_tag(name:"risk_factor", value:"Critical");
  script_cve_id("CVE-2009-3473");
  script_name("IBM DB2 Unspecified Vulnerability (Win)");
  desc = "
  Overview: The host is installed with IBM DB2 and is prone to unspecified
  vulnerability.

  Vulnerability Insight:
  An unspecified error in the handling of 'SET SESSION AUTHORIZATION'
  statements that can be exploited to execute the statement without having
  the required privileges.

  Impact: Unknown impact.

  Impact Level: System/Application.

  Affected Software/OS:
  IBM DB2 version 9.1 prior to Fixpak 8

  Fix:Update DB2 9.1 Fixpak 8 or later.
  http://www-01.ibm.com/support/docview.wss?rs=71&uid=swg27007053

  References:
  http://secunia.com/advisories/36890
  http://www-01.ibm.com/support/docview.wss?uid=swg21403619
  http://www-01.ibm.com/support/docview.wss?uid=swg21386689

  CVSS Score:
    CVSS Base Score      : 10.0 (AV:N/AC:L/Au:NR/C:C/I:C/A:C)
    CVSS Temporal Score  : 7.4
  Risk factor: High";

  script_description(desc);
  script_summary("Check for the version of IBM DB2");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 Intevation GmbH");
  script_family("General");
  script_dependencies("secpod_ibm_db2_detect_win_900218.nasl");
  script_require_keys("Win/IBM-db2/Ver");
  exit(0);
}


include("version_func.inc");

ibmVer = get_kb_item("Win/IBM-db2/Ver");
if(!ibmVer){
  exit(0);
}

# Check for IBM DB2 Products Version 9.1 before FP8
# IBM DB2 9.1 FP8 => 9.1.800.1023
if(version_in_range(version:ibmVer, test_version:"9.1",
                                    test_version2:"9.1.800.1022")){
  security_hole(0);
}
