###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_mozilla_prdts_js_uri_xss_vuln_sep09_lin.nasl 4411 2009-09-04 20:03:26Z sep $
#
# Mozilla Product(s) 'javascript:' URI XSS Vulnerability - Sep09 (Linux)
#
# Authors:
# Sharath S <sharaths@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800886);
  script_version("$Revision: 1.0 $");
  script_tag(name:"cvss_base", value:"4.3");
  script_tag(name:"risk_factor", value:"Medium");
  script_cve_id("CVE-2009-3010", "CVE-2009-3014");
  script_name("Mozilla Product(s) 'javascript:' URI XSS Vulnerability - Sep09 (Linux)");
  desc = "
  Overview: This host is installed with Mozilla Product(s) and is prone to
  Cross-Site Scripting vulnerability.

  Vulnerability Insight:
  Application fails to sanitise the 'javascript:' and 'data:' URIs in Refresh
  headers or Location headers in HTTP responses, which can be exploited via
  vectors related to injecting a Refresh header or Location HTTP response header.

  Impact:
  Successful exploitation will let the attackers to conduct Cross-Site Scripting
  attacks in the victim's system.

  Impact Level: Application

  Affected Software/OS:
  Mozilla, Firefox version 3.0.13 and prior, 3.5 and 3.6/3.7 a1 pre
           Moziila Browser 1.7.x and prior.
           Seamonkey 1.1.17 on Linux.

  Fix: No solution or patch is available as on 04th September, 2009. Information
  regarding this issue will be updated once the solution details are available.
  For updates refer, http://www.mozilla.org/

  References:
  http://websecurity.com.ua/3315/
  http://websecurity.com.ua/3323/
  http://websecurity.com.ua/3373/
  http://websecurity.com.ua/3386/
  http://www.securityfocus.com/archive/1/archive/1/506163/100/0/threaded

  CVSS Score:
    CVSS Base Score     : 4.3 (AV:N/AC:M/Au:NR/C:N/I:P/A:N)
    CVSS Temporal Score : 3.9
  Risk factor: Medium";

  script_description(desc);
  script_summary("Check for the version of Mozilla Product(s)");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 Intevation GmbH");
  script_family("General");
  script_dependencies("gb_firefox_detect_lin.nasl", "gb_seamonkey_detect_lin.nasl",
                      "gb_mozilla_detect_lin.nasl");
  script_require_keys("Firefox/Linux/Ver", "Seamonkey/Linux/Ver",
                      "Mozilla/Linux/Ver");
  exit(0);
}


include("version_func.inc");

# Firefox Check
ffVer = get_kb_item("Firefox/Linux/Ver");

if(ffVer)
{
  # Grep for Firefox version <= 3.0.13 or 3.5 or 3.6 a1 pre or 3.7 a1 pre
  if(version_is_less_equal(version:ffVer, test_version:"3.0.13")||
    version_is_equal(version:ffVer, test_version:"3.5"))
  {
    security_warning(0);
    exit(0);
  }
  # Grep for Firefox version 3.6 a1 pre or 3.7 a1 pre
  else if(ffVer =~ "^3\.[6|7]a1pre")
  {
    security_warning(0);
    exit(0);
  }
}

# Seamonkey Check
smVer = get_kb_item("Seamonkey/Linux/Ver");
if(smVer != NULL)
{
  # Grep for Seamonkey version 1.1.17
  if(version_is_equal(version:smVer, test_version:"1.1.17"))
  {
    security_warning(0);
    exit(0);
  }
}

# For Mozilla Browser
mbVer = get_kb_item("Mozilla/Linux/Ver");
if(mbVer)
{
  # Check for Mozilla Browser Version 1.7.x and prior
  if(version_is_less_equal(version:mbVer, test_version:"1.7.13")){
    security_warning(0);
  }
}
