###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_pidgin_msnslp_dir_trav_vuln_win.nasl 6723 2010-01-14 14:48:17Z jan $
#
# Pidgin MSN Custom Smileys File Disclosure Vulnerability (Win)
#
# Authors:
# Antu Sanadi <santu@secpod.com>
#
# Copyright:
# Copyright (c) 2010 Greenbone Networks GmbH, http://www.greenbone.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800421);
  script_version("$Revision: 7614 $: 1.0");
  script_tag(name:"cvss_base", value:"5.0");
  script_tag(name:"risk_factor", value:"Medium");
  script_cve_id("CVE-2010-0013");
  script_name("Pidgin MSN Custom Smileys File Disclosure Vulnerability (Win)");
  desc = "
  Overview: This host has Pidgin installed and is prone to File Disclosure
  vulnerability

  Vulnerability Insight:
  This issue is caused due to error in 'slp.c' within the 'MSN protocol plugin'
  in 'libpurple' when processing application/x-msnmsgrp2p MSN emoticon (aka custom
  smiley) request.

  Impact:
  Attackers can exploit this issue to gain knowledge of sensitive information
  via directory traversal attacks.

  Impact Level: Application

  Affected Software/OS:
  Pidgin version prior to 2.6.4 on Windows.

  Fix:  Apply the patch or upgrade to Pidgin version 2.6.5
  http://pidgin.im/download
  http://developer.pidgin.im/viewmtn/revision/info/c64a1adc8bda2b4aeaae1f273541afbc4f71b810

  *****
  NOTE: Please ignore this warning if the patch is already applied.
  *****

  References:
  http://secunia.com/advisories/37953/
  http://www.pidgin.im/news/security/?id=42
  http://www.vupen.com/english/advisories/2009/3662

  CVSS Score:
    CVSS Base Score      : 5.0 (AV:N/AC:L/Au:NR/C:P/I:N/A:N)
    CVSS Temporal Score  : 3.7
  Risk factor : Medium";

  script_description(desc);
  script_summary("Check for the version of Pidgin");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (c) 2010 Greenbone Networks GmbH");
  script_family("General");
  script_dependencies("secpod_pidgin_detect_win.nasl");
  script_require_keys("Pidgin/Win/Ver");
  exit(0);
}


include("version_func.inc");

pidginVer = get_kb_item("Pidgin/Win/Ver");
if(pidginVer != NULL)
{
  if(version_is_less(version:pidginVer, test_version:"2.6.5")){
    security_warning(0);
  }
}
