###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_sun_java_jre_int_overflow_vuln_aug09.nasl 3821 2009-08-19 13:03:20Z aug $
#
# Sun Java JDK/JRE JPEG Images Integer Overflow Vulnerability - Aug09
#
# Authors:
# Sharath S <sharaths@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800868);
  script_version("$Revision: 1.0 $");
  script_tag(name:"cvss_base", value:"10.0");
  script_tag(name:"risk_factor", value:"Critical");
  script_cve_id("CVE-2009-2674", "CVE-2009-2476", "CVE-2009-2690",
                "CVE-2009-2716", "CVE-2009-2719", "CVE-2009-2720");
  script_bugtraq_id(35942);
  script_name("Sun Java JDK/JRE JPEG Images Integer Overflow Vulnerability - Aug09");
  desc = "

  Overview: This host is installed with Sun Java JDK/JRE and is prone to Integer
  Overflow vulnerability.

  Vulnerability Insight:
  - Integer overflow occurs in JRE while vectors involving an untrusted Java Web
    Start application that grants permissions to itself, related to parsing of
    JPEG images.
  - Error in the Java Management Extensions (JMX) implementation which does not
    properly enforce OpenType checks.
  - Error in encoder which grants read access to private variables with unspecified
    names via an untrusted applet or application.
  - The plugin functionality does not properly implement version selection,
    which can be exploited by 'old zip and certificate handling' via unknown
    vectors.
  - Unspecified error in the 'javax.swing.plaf.synth.SynthContext.isSubregion'
    method in the Swing implementation which causes NullPointerException via
    unknown vectors.
  - Error in Java Web Start implementation which causes NullPointerException
    via a crafted '.jnlp' file.

  Impact:
  Successful exploitation will let the remote attackers to gain sensitive
  information, and can cause Denial of Service in the context of the affected
  system.

  Impact Level: System/Application

  Affected Software/OS:
  Sun Java JDK/JRE version 6 before Update 15.

  Fix: Upgrade to JDK/JRE version 6 Update 15
  http://java.sun.com/javase/downloads/index.jsp
  or
  Apply the patch from below link,
  http://sunsolve.sun.com/search/document.do?assetkey=1-21-125136-16-1
  http://sunsolve.sun.com/search/document.do?assetkey=1-21-125139-16-1

  *****
  NOTE: Ignore this warning if above mentioned patch is already applied.
  *****

  References:
  http://secunia.com/advisories/36159
  http://secunia.com/advisories/36162
  http://secunia.com/advisories/36176
  http://secunia.com/advisories/36180
  http://java.sun.com/javase/6/webnotes/6u15.html
  http://www.zerodayinitiative.com/advisories/ZDI-09-050/
  http://sunsolve.sun.com/search/document.do?assetkey=1-66-263428-1

  CVSS Score:
    CVSS Base Score     : 10.0 (AV:N/AC:L/Au:NR/C:C/I:C/A:C)
    CVSS Temporal Score : 7.4
  Risk factor: High";

  script_description(desc);
  script_summary("Check for the Version of Sun Java JDK/JRE");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 Intevation GmbH");
  script_family("General");
  script_dependencies("gb_java_prdts_detect_win.nasl",
                      "gb_java_prdts_detect_lin.nasl");
  script_require_keys("Sun/Java/JRE/Win/Ver", "Sun/Java/JRE/Linux/Ver",
                      "Sun/Java/JDK/Win/Ver");
  exit(0);
}


include("version_func.inc");

# Get KB for JDK Version On Windows
jdkVer = get_kb_item("Sun/Java/JDK/Win/Ver");
jdkVer = ereg_replace(pattern:"_", string:jdkVer, replace: ".");

if(jdkVer)
{
  # Check for 1.6 < 1.6.0_15 (6 Update 15)
  if(version_in_range(version:jdkVer, test_version:"1.6", test_version2:"1.6.0.14"))
  {
    security_hole(0);
    exit(0);
  }
}

# Get KB for JRE Version On Windows
jreVer = get_kb_item("Sun/Java/JRE/Win/Ver");

if(isnull(jreVer))
{
  # Get KB for JRE/JDK Version On Linux
  jreVer = get_kb_item("Sun/Java/JRE/Linux/Ver");
  if(isnull(jreVer))
    exit(0);
}

jreVer = ereg_replace(pattern:"_", string:jreVer, replace: ".");
jreVer = ereg_replace(pattern:"-b[0-9][0-9]", string:jreVer, replace:"");
if(jreVer)
{
  # Check for 1.6 < 1.6.0_15 (6 Update 15)
  if(version_in_range(version:jreVer, test_version:"1.6", test_version2:"1.6.0.14")){
    security_hole(0);
  }
}
