###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_ultraiso_bof_vuln.nasl 1559 2009-04-08 16:30:29Z apr $
#
# UltraISO Buffer Overflow Vulnerability
#
# Authors:
# Sujit Ghosal <sghosal@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800275);
  script_version("$Revision: 1.0 $");
  script_tag(name:"cvss_base", value:"10.0");
  script_tag(name:"risk_factor", value:"Critical");
  script_cve_id("CVE-2009-1260");
  script_bugtraq_id(34363);
  script_name("UltraISO Buffer Overflow Vulnerability");
  desc = "

  Overview: This host is running UltraISO and is prone to Stack-Based Buffer
  Overflow Vulnerability.

  Vulnerability Insight:
  This flaw is caused due to inadequate boundary check while processing 'CCD'
  or 'IMG' files.

  Impact:
  Successful exploitation will let the attacker execute arbitrary codes in the
  context of the application and can cause stack overflow or denial of service.

  Impact level: Application.

  Affected Software/OS:
  UltraISO version 9.3.3.2685 and prior.

  Fix: Upgrade to UltraISO version 9.3.6.2750 or later
  updates refer, http://www.ezbsystems.com/ultraiso

  References:
  http://secunia.com/advisories/34581
  http://www.milw0rm.com/exploits/8343
  http://xforce.iss.net/xforce/xfdb/49672

  CVSS Score:
    CVSS Base Score     : 10.0 (AV:N/AC:L/Au:NR/C:C/I:C/A:C)
    CVSS Temporal Score : 9.0
  Risk factor: Critical";

  script_description(desc);
  script_summary("Check for the version of UltraISO");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 Intevation GmbH");
  script_family("Buffer overflow");
  script_dependencies("gb_ultraiso_detect.nasl");
  script_require_keys("UltraISO/Ver");
  exit(0);
}


include("version_func.inc");

ultraVer = get_kb_item("UltraISO/Ver");
if(!ultraVer){
  exit(0);
}

# Grep for UltraISO maker version 9.3.3.2685 or prior.
if(version_is_less_equal(version:ultraVer, test_version:"9.3.3.2685")){
  security_hole(0);
}
