###############################################################################
# OpenVAS Vulnerability Test
# $Id: nginx_36490.nasl 7516 2010-05-04 08:24:56Z chandra $
#
# nginx WebDAV Multiple Directory Traversal Vulnerabilities
#
# Authors:
# Michael Meyer
#
# Copyright:
# Copyright (c) 2009 Greenbone Networks GmbH
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if (description)
{
 script_id(100275);
 script_bugtraq_id(36490);
 script_version ("1.0-$Revision: 7516 $");
 script_tag(name:"risk_factor", value:"Medium");

 script_name("nginx WebDAV Multiple Directory Traversal Vulnerabilities");

desc = "Overview:
The 'nginx' program is prone to multiple directory-traversal
vulnerabilities because the software fails to sufficiently sanitize
user-supplied input.

An attacker can exploit these issues using directory-traversal strings
('../') to overwrite arbitrary files outside the root directory.

These issues affect nginx 0.7.61 and 0.7.62; other versions may also
be affected.

References:
http://www.securityfocus.com/bid/36490
http://nginx.net/
http://www.securityfocus.com/archive/1/506662

Risk factor : Medium";

 script_description(desc);
 script_summary("Determine if nginx Version is 0.7.61 ot 0.7.62");
 script_category(ACT_GATHER_INFO);
 script_family("Web Servers");
 script_copyright("This script is Copyright (C) 2009 Greenbone Networks GmbH");
 script_dependencies("nginx_detect.nasl");
 script_require_ports("Services/www", 80);
 exit(0);
}

     
include("http_func.inc");
include("http_keepalive.inc");
include("version_func.inc");

port = get_http_port(default:80);
if(!get_port_state(port))exit(0);

if(!vers = get_kb_item(string("nginx/", port, "/version")))exit(0);
if(!isnull(vers) && vers >!< "unknown") {

  if(
     version_is_equal(version: vers, test_version: "0.7.61") ||
     version_is_equal(version: vers, test_version: "0.7.62")
    ) {
      security_warning(port:port);
      exit(0);
  }

}

exit(0);

