###############################################################################
# OpenVAS Vulnerability Test
# $Id: secpod_sorinara_mp3_player_bof_vuln.nasl 2344 2009-05-18 15:56:36Z may $
#
# Sorinara Soritong MP3 Player Stack Overflow Vulnerability
#
# Authors:
# Antu Sanadi <santu@secpod.com>
#
# Copyright:
# Copyright (c) 2009 SecPod, http://www.secpod.com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(900650);
  script_version("$Revision: 1.0 $");
  script_tag(name:"cvss_base", value:"9.3");
  script_tag(name:"risk_factor", value:"Critical");
  script_cve_id("CVE-2009-1643");
  script_bugtraq_id(34863);
  script_name("Sorinara Soritong MP3 Player Stack Overflow Vulnerability");
  desc = "

  Overview: This host is running Sorinara Soritong MP3 Player and is prone to
  Stack Overflow Vulnerability.

  Vulnerability Insight:
  This flaw is caused due to an improper boundary checking when processing
  '.m3u' files.

  Impact:
  Successful exploitation will let the attacker craft a malicious m3u playlist
  file and trick the user to open the application which will cause stack overflow
  in the affected system and will crash the application.

  Affected Software/OS:
  Soritong MP3 Player version 1.0 and prior

  Fix: No solution or patch is available as on 29th May, 2009. Information
  regarding this issue will be updated once the solution details are available.
  For updates refer, http://www.sorinara.com/soritong

  References:
  http://www.milw0rm.com/exploits/8624
  http://xforce.iss.net/xforce/xfdb/50398

  CVSS Score:
    CVSS Base Score      : 9.3 (AV:N/AC:M/Au:NR/C:C/I:C/A:C)
    CVSS Temporal Score  : 8.4
  Risk factor: Critical";

  script_description(desc);
  script_summary("Check for the version of Sorinara Soritong MP3 Player");
  script_category(ACT_GATHER_INFO);
  script_copyright("Copyright (C) 2009 SecPod");
  script_family("Buffer overflow");
  script_dependencies("secpod_reg_enum.nasl");
  script_require_keys("SMB/WindowsVersion");
  script_require_ports(139,445);
  exit(0);
}


include("smb_nt.inc");
include("version_func.inc");
include("secpod_smb_func.inc");

if(!get_kb_item("SMB/WindowsVersion")){
  exit(0);
}

key = "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\SoriTong\";
appName = registry_get_sz(key:key, item:"DisplayName");
if("SoriTong" >< appName)
{
  readmePath = registry_get_sz(key:key, item:"UninstallString");
  if(!readmePath){
    exit(0);
  }

  readmePath = readmePath - "\uninstall.exe /uninstall";
  readmePath = readmePath + "\Help";

  share = ereg_replace(pattern:"([A-Z]):.*", replace:"\1$", string:readmePath);
  file =  ereg_replace(pattern:"[A-Z]:(.*)", replace:"\1",
                       string:readmePath + "\whatsnew.html");

  readmeText = read_file(share:share, file:file, offset:0, count:500);
  if(!readmeText){
    exit(0);
  }

  saritongVer = eregmatch(pattern:"Version ([0-9.]+)", string:readmeText);
  if(saritongVer[1] != NULL)
  {
    if(version_is_less_equal(version:saritongVer[1], test_version:"1.0")){
      security_hole(0);
    }
  }
}
