###############################################################################
# OpenVAS Vulnerability Test
# $Id: yaws_webserver_37716.nasl 7592 2010-05-07 14:44:11Z chandra $
#
# Yaws Terminal Escape Sequence in Logs Command Injection Vulnerability
#
# Authors:
# Michael Meyer
#
# Copyright:
# Copyright (c) 2010 Greenbone Networks GmbH
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if (description)
{
 script_id(100446);
 script_bugtraq_id(37716);
 script_cve_id("CVE-2009-4495");
 script_version ("1.0-$Revision: 7592 $");
 script_tag(name:"cvss_base", value:"5.0");
 script_tag(name:"risk_factor", value:"Medium");

 script_name("Yaws Terminal Escape Sequence in Logs Command Injection Vulnerability");

desc = "Overview:
Yaws is prone to a command-injection vulnerability because it fails to
adequately sanitize user-supplied input in logfiles.

Attackers can exploit this issue to execute arbitrary commands in
a terminal.

Yaws 1.85 is vulnerable; other versions may also be affected.

References:
http://www.securityfocus.com/bid/37716
http://yaws.hyber.org/
http://www.securityfocus.com/archive/1/508830

Risk factor : Medium";

 script_description(desc);
 script_summary("Determine if Yaws version is <= 1.85");
 script_category(ACT_GATHER_INFO);
 script_family("Web Servers");
 script_copyright("This script is Copyright (C) 2010 Greenbone Networks GmbH");
 script_dependencies("find_service.nes");
 script_require_ports("Services/www", 80);
 exit(0);
}

     
include("http_func.inc");
include("version_func.inc");

port = get_http_port(default:80);
if(!get_port_state(port))exit(0);

banner = get_http_banner(port: port);
if(!banner)exit(0);

if("Server: Yaws/" >!< banner)exit(0);
version = eregmatch(pattern:"Server: Yaws/([0-9.]+)", string: banner);
if(isnull(version[1]))exit(0);

if(version_is_less_equal(version: version[1], test_version: "1.85")) {
  security_warning(port:port);
  exit(0);
}


exit(0);

